Print method for objects of class limitmeta.
# S3 method for limitmeta
print(
x,
backtransf = x$backtransf,
digits = gs("digits"),
header = TRUE,
pscale = x$x$pscale,
irscale = x$x$irscale,
irunit = x$x$irunit,
digits.stat = gs("digits.stat"),
digits.pval = gs("digits.pval"),
digits.Q = gs("digits.Q"),
digits.tau2 = gs("digits.tau2"),
digits.I2 = gs("digits.I2"),
scientific.pval = gs("scientific.pval"),
big.mark = gs("big.mark"),
print.Rb = gs("print.Rb"),
warn.backtransf = FALSE,
...
)An object of class limitmeta.
A logical indicating whether results should be
back transformed in printouts and plots. If
backtransf=TRUE (default), results for sm="OR" are
printed as odds ratios rather than log odds ratio, for example.
Minimal number of significant digits, see
print.default.
A logical indicating whether information on title of meta-analysis, comparison and outcome should be printed at the beginning of the printout.
A numeric giving scaling factor for printing of
single event probabilities, i.e. if argument sm is equal
to "PLOGIT", "PLN", "PRAW", "PAS", or
"PFT".
A numeric defining a scaling factor for printing of
rates, i.e. if argument sm is equal to "IR",
"IRLN", "IRS", or "IRFT".
A character specifying the time unit used to calculate rates, e.g. person-years.
Minimal number of significant digits for z- or
t-value, see print.default.
Minimal number of significant digits for p-value
of overall treatment effect, see print.default.
Minimal number of significant digits for
heterogeneity statistic Q, see print.default.
Minimal number of significant digits for
between-study variance, see print.default.
Minimal number of significant digits for I-squared
and Rb statistic, see print.default.
A logical specifying whether p-values should be printed in scientific notation, e.g., 1.2345e-01 instead of 0.12345.
A character used as thousands separator.
A logical specifying whether heterogeneity statistic Rb should be printed.
A logical indicating whether a warning should be printed if backtransformed proportions and rates are below 0 and backtransformed proportions are above 1.
Additional arguments (ignored).
Guido Schwarzer guido.schwarzer@uniklinik-freiburg.de
This function prints the main results of a limit meta-analysis (Rücker et al., 2011).
limitmeta, summary.limitmeta,
print.summary.limitmeta
data(Moore1998)
m1 <- metabin(succ.e, nobs.e, succ.c, nobs.c,
data = Moore1998, sm = "OR", method = "Inverse")
print(limitmeta(m1), digits = 2)
Run the code above in your browser using DataLab